#!/bin/sh
#
# Script to archive appropriate folders
# to the Archive folder.
#
# Tony Paterson
# May 2007
#

# Source function library.
if [ -x /etc/rc.d/init.d/functions ]; then
. /etc/rc.d/init.d/functions
fi

#
# Get the date in the format "Day of Week" and time
# This will mean that we will effectively keep a weeks backup
#
SHORTDATE=`date +%a`


#
# User config section
#
SVRNAME="VMValiant"
ArchiveFolder=/srv/backup/smb
LOGFILE=$ArchiveFolder/daily_backup.log


# Cleanup backup dir
rm -Rf $ArchiveFolder
mkdir -p $ArchiveFolder


#
# Describe the names of the folders to be backed up
#
# NOTE: "BackupFolder[]" should be an absolute path without
#       the leading "/". Thus "/shares/smb/docs" would now
#       simply be "shares/dmb/docs"
#
BackupFolder[0]=/srv/wordpress
BackupFolderName[0]=WordPress_Data
BackupFolder[1]=/srv/wordpressdev
BackupFolderName[1]=WordPress_Dev_Data
BackupFolder[2]=/srv/www/wordpress
BackupFolderName[2]=WordPress_WWW_Dir
BackupFolder[3]=/srv/www/wordpressdev
BackupFolderName[3]=WordPress_Dev_WWW_Dir
BackupFolder[4]=/etc/httpd
BackupFolderName[4]=HTTPD_Conf_Dir
BackupFolder[5]=/srv/conf
BackupFolderName[5]=Conf_Dir
BackupFolder[6]=/srv/www/wordpressjosh
BackupFolderName[6]=WordPress_Josh_Data

#
# This section backs up a section of misc files
#
FileArchiveDir=/srv/backup/smb/misc_files
BackupFile[0]=/etc/httpd/conf/httpd.conf
BackupFile[1]=/etc/samba/smb.conf
BackupFile[2]=/etc/ssh/ssh_config




##############################
#
# Begin main backup section
#
echo " " >> $LOGFILE
echo " " >> $LOGFILE
echo "Begining smb file and folder backup " `date` "..."
echo "Begining smb file and folder backup " `date` "..." >> $LOGFILE


#
# Step through each backup folder and archive
#
for (( i = 0; i < ${#BackupFolder[@]} ; i++))
do
   echo "Tar and Gzipping folder ${BackupFolder[$i]}..."
   echo "Tar and Gzipping folder ${BackupFolder[$i]}..." >> $LOGFILE
   ARCHIVE_FULL_NAME="$ArchiveFolder/${BackupFolderName[$i]}""_on_$SVRNAME"".tar.gz"
   tar -zcf $ARCHIVE_FULL_NAME -C / ${BackupFolder[$i]}
done


#
# Backup through individual files
#
rm -Rf $FileArchiveDir
mkdir -p $FileArchiveDir
for (( i = 0; i < ${#BackupFile[@]} ; i++))
do
   echo "Copying file ${BackupFile[$i]}..."
   echo "Copying file ${BackupFile[$i]}..." >> $LOGFILE
   cp ${BackupFile[$i]} $FileArchiveDir
done

